@@ -6,9 +6,9 @@ from .exceptions import *
 from .interface import *
 from .interpreter import *
 from .utils import *
-from .verb import Verb
+from .verb import Verb as Verb
 
-__version__ = "3.0.4"
+__version__ = "3.1.0"
 
 
 class VersionInfo(namedtuple("VersionInfo", "major minor micro")):
