@@ -9,6 +9,7 @@ from .exceptions import (
     StopError,
     TagScriptError,
     WorkloadExceededError,
+    BlockNameDuplicateError,
 )
 from .interface import Adapter, Block
 from .utils import maybe_await
@@ -160,6 +161,12 @@ class Interpreter:
 
     def __init__(self, blocks: List[Block]) -> None:
         self.blocks: List[Block] = blocks
+        self._blocknames = []
+        for block in blocks:
+            for name in block.ACCEPTED_NAMES:
+                if block in self._blocknames:
+                    raise BlockNameDuplicateError("Duplicate block name", block)
+                self._blocknames.append(name)
 
     def __repr__(self) -> str:
         return f"<{type(self).__name__} blocks={self.blocks!r}>"
